%COMPUTE_ADDOT
% Computute angular accelerations /radians per second per second
% for an idealised double pendulum dynamic system.
%
% LAST UPDATED by Andy French. 11-Dec-2005
%
% Syntax: [addot1,addot2]=compute_addot(m1,m2,l1,l2,g,a1,a2,adot1,adot2)
%
% m1      - Mass of bob 1 /kg
% m2      - Mass of bob 2 /kg
% l1      - Length of the (rigid) string joining the fixed pivot point to bob 1 /m
% l2      - Length of the (rigid) joining bob2 to bob 1 /m
% g       - Gravitational field strength /ms^-2
% a1      - Angle of bob1 measured anticlockwise from the vertical /radians
% a2      - Angle of bob1 measured anticlockwise from the vertical /radians
% adot1   - Angular velocity of bob 1 /radians s^-1
% adot2   - Angular velocity of bob 2 /radians s^-1
%
% addot1  - Angular acceleration of bob 1 /radians s^-1
% addot2  - Angular acceleration of bob 2 /radians s^-1

function [addot1,addot2]=compute_addot(m1,m2,l1,l2,g,a1,a2,adot1,adot2)

if m1==0
    %Single pendulum. Bob acceleations equate - rigid string length of
    %l1+l2
    addot2=-(g/(l1+l2))*sin(a2);
    addot1=addot2;
else
    %Double pendulum
    U=m2*g*sin(a2).*cos(a1-a2)-m2*l1*adot1.*sin(a1-a2).*cos(a1-a2)-...
        g*(m1+m2)*sin(a1)-m2*l2*adot2.*adot2.*sin(a1-a2);
    V=-m2*l1*cos(a1-a2).*cos(a1-a2) + l1*(m1+m2);
    addot1=U./V;
    W=m2*l1.*adot1.*adot2.*sin(a1-a2) - m2*g*sin(a2) - m2*l1*addot1.*cos(a1-a2);
    addot2=W/(m2*l2);
end

%End of code