%TOTAL_ENERGY
% Compute total energy E of Double Pendulum system
%
% LAST UPDATED by Andy French 11-Dec-2005
%
% a1      - Angle of bob 1 (radians) from vertical
% a2      - Angle of bob 1 (radians) from vertical
% adot1   - Angular velocity of bob 1
% adot2   - Angular velocity of bob 2
% m1      - Mass of bob 1 /kg
% m2      - Mass of bob 2 /kg
% l1      - Length of rigid string joining fixed pivot to bob 1 /m
% l2      - Length of rigid string joining bob 1 to bob 2 /m
% g       - Gravitational field strength /ms^-2
%
% E       - Total energy of system /joules
% A,B,C   - E = A + B*adot2*adot2 + C*adot2

function [E,A,B,C]=total_energy(a1,a2,adot1,adot2,m1,m2,l1,l2,g)

%Compute coefficients of quadratic expression in adot2
A=0.5*(m1+m2)*l1*l1*adot1.*adot1  -(m1+m2)*g*l1*cos(a1) - m2*g*l2*cos(a2);
B=0.5*m2*l2*l2;
C=m2*l1*l2*adot1.*cos(a1-a2);

%Compute total energy
E=A + B*adot2.*adot2 + C.*adot2;

%End of code